@@ -14,8 +14,9 @@ class Server(object):
     for websocket and long-polling transports.
 
     :param client_manager: The client manager instance that will manage the
-                           client list. By default the client list is stored
-                           in a simple in-memory structure.
+                           client list. When this is omitted, the client list
+                           is stored in an in-memory structure, so the use of
+                           multiple connected servers is not possible.
     :param logger: To enable logging set to ``True`` or pass a logger object to
                    use. To disable logging set to ``False``.
     :param binary: ``True`` to support binary payloads, ``False`` to treat all
@@ -61,9 +62,6 @@ class Server(object):
     """
     def __init__(self, client_manager=None, logger=False, binary=False,
                  json=None, **kwargs):
-        if client_manager is None:
-            client_manager = base_manager.BaseManager(self)
-        self.manager = client_manager
         engineio_options = kwargs
         engineio_logger = engineio_options.pop('engineio_logger', None)
         if engineio_logger is not None:
@@ -96,6 +94,11 @@ class Server(object):
                     self.logger.setLevel(logging.ERROR)
                 self.logger.addHandler(logging.StreamHandler())
 
+        if client_manager is None:
+            client_manager = base_manager.BaseManager()
+        client_manager.initialize(self)
+        self.manager = client_manager
+
     def on(self, event, handler=None, namespace=None):
         """Register an event handler.
 
@@ -247,7 +250,7 @@ class Server(object):
         """
         namespace = namespace or '/'
         self.logger.info('room %s is closing [%s]', room, namespace)
-        self.manager.close_room(namespace, room)
+        self.manager.close_room(room, namespace)
 
     def rooms(self, sid, namespace=None):
         """Return the rooms a client is in.
@@ -299,14 +302,23 @@ class Server(object):
         """
         return self.eio.handle_request(environ, start_response)
 
+    def start_background_task(self, target, *args, **kwargs):
+        self.eio.start_background_task(target, *args, **kwargs)
+
     def _emit_internal(self, sid, event, data, namespace=None, id=None):
         """Send a message to a client."""
         if six.PY2 and not self.binary:
             binary = False  # pragma: nocover
         else:
             binary = None
+        # tuples are expanded to multiple arguments, everything else is sent
+        # as a single argument
+        if isinstance(data, tuple):
+            data = list(data)
+        else:
+            data = [data]
         self._send_packet(sid, packet.Packet(packet.EVENT, namespace=namespace,
-                                             data=[event, data], id=id,
+                                             data=[event] + data, id=id,
                                              binary=binary))
 
     def _send_packet(self, sid, pkt):
@@ -329,6 +341,7 @@ class Server(object):
             self.manager.disconnect(sid, namespace)
             self._send_packet(sid, packet.Packet(packet.ERROR,
                                                  namespace=namespace))
+            return False
         else:
             self._send_packet(sid, packet.Packet(packet.CONNECT,
                                                  namespace=namespace))
@@ -358,10 +371,9 @@ class Server(object):
         r = self._trigger_event(data[0], namespace, sid, *data[1:])
         if id is not None:
             # send ACK packet with the response returned by the handler
+            # tuples are expanded as multiple arguments
             if isinstance(r, tuple):
                 data = list(r)
-            elif isinstance(r, list):
-                data = r
             else:
                 data = [r]
             if six.PY2 and not self.binary:
@@ -387,7 +399,7 @@ class Server(object):
     def _handle_eio_connect(self, sid, environ):
         """Handle the Engine.IO connection event."""
         self.environ[sid] = environ
-        self._handle_connect(sid, '/')
+        return self._handle_connect(sid, '/')
 
     def _handle_eio_message(self, sid, data):
         """Dispatch Engine.IO messages."""
